@@ -14,7 +14,7 @@
  * under the License.
  */
 
-import { Button, FormGroup, InputGroup, MenuItem } from 'react-bootstrap';
+import { FormGroup, InputGroup, MenuItem } from 'react-bootstrap';
 import PropTypes from 'prop-types';
 import React from 'react';
 import { Field, reduxForm } from 'redux-form';
@@ -30,7 +30,9 @@ class ToolbarFiltersForm extends React.Component {
   renderFilterByOptions() {
     const { options } = this.props;
     return Object.keys(options).map(k => (
-      <MenuItem key={k} eventKey={k}>{options[k]}</MenuItem>
+      <MenuItem key={k} eventKey={k}>
+        {options[k]}
+      </MenuItem>
     ));
   }
 
@@ -48,24 +50,26 @@ class ToolbarFiltersForm extends React.Component {
   }
 
   render() {
-    const { formatSelectValue, handleSubmit, options, ...rest } = this.props;
+    const { formatSelectValue, handleSubmit, options, id } = this.props;
     return (
-      <form {...rest} onSubmit={handleSubmit(this.submit.bind(this))}>
+      <form id={id} onSubmit={handleSubmit(this.submit.bind(this))}>
         <FormGroup className="toolbar-pf-filter">
-          {options
-            ? <InputGroup>
-                <InputGroup.Button>
-                  <Field
-                    name="filterBy"
-                    component={DropdownSelect}
-                    format={formatSelectValue}
-                  >
-                    {this.renderFilterByOptions()}
-                  </Field>
-                </InputGroup.Button>
-                {this.renderFilterStringField()}
-              </InputGroup>
-            : this.renderFilterStringField()}
+          {options ? (
+            <InputGroup>
+              <InputGroup.Button>
+                <Field
+                  name="filterBy"
+                  component={DropdownSelect}
+                  format={formatSelectValue}
+                >
+                  {this.renderFilterByOptions()}
+                </Field>
+              </InputGroup.Button>
+              {this.renderFilterStringField()}
+            </InputGroup>
+          ) : (
+            this.renderFilterStringField()
+          )}
         </FormGroup>
       </form>
     );
@@ -75,6 +79,7 @@ ToolbarFiltersForm.propTypes = {
   form: PropTypes.string.isRequired,
   formatSelectValue: PropTypes.func,
   handleSubmit: PropTypes.func.isRequired,
+  id: PropTypes.string,
   initialValues: PropTypes.object,
   initialize: PropTypes.func.isRequired,
   onSubmit: PropTypes.func.isRequired,
